choose

package module
v0.0.0-...-725949f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 25, 2018 License: MIT Imports: 0 Imported by: 0

README

N choose K for Go/Golang

Go Report Card Go Doc Release

package choose implements the N choose K formula, or the binomial coefficient formula. See https://en.wikipedia.org/wiki/Binomial_coefficient for more.

Installation
go get github.com/cannona/choose

Documentation

Overview

Package choose implements the N choose K formula, or the binomial coefficient formula. See https://en.wikipedia.org/wiki/Binomial_coefficient for more.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Choose

func Choose(n, k int64) int64

Choose calculates n choose k. Overflows are not detected, and Choose panics if n >= k >= 0 is violated.

Types

This section is empty.

Jump to